@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -63,24 +63,18 @@ if (isset($_REQUEST['output']) && $_REQUEST['output'] == 'ajax') {
 			'final' => true
 		];
 
-		$validator = new CRegexValidator([
-			'messageInvalid' => _('Regular expression must be a string'),
-			'messageRegex' => _('Incorrect regular expression "%1$s": "%2$s"')
-		]);
-
-		foreach ($ajaxData['expressions'] as $id => $expression) {
-			if (!in_array($expression['expression_type'], [EXPRESSION_TYPE_FALSE, EXPRESSION_TYPE_TRUE]) ||
-				$validator->validate($expression['expression'])
-			) {
-				$match = CGlobalRegexp::matchExpression($expression, $ajaxData['testString']);
-
-				$result['expressions'][$id] = $match;
-			} else {
-				$match = false;
-				$result['errors'][$id] = $validator->getError();
+		if (array_key_exists('expressions', $ajaxData)) {
+			foreach ($ajaxData['expressions'] as $id => $expression) {
+				try {
+					validateRegexp([$expression]);
+					$result['expressions'][$id] = CGlobalRegexp::matchExpression($expression, $ajaxData['testString']);
+					$result['final'] = $result['final'] && $result['expressions'][$id];
+				}
+				catch (Exception $e) {
+					$result['errors'][$id] = $e->getMessage();
+					$result['final'] = false;
+				}
 			}
-
-			$result['final'] = $result['final'] && $match;
 		}
 
 		$ajaxResponse->success($result);
@@ -101,16 +95,21 @@ if (isset($_REQUEST['regexpid'])) {
 		access_deny();
 	}
 }
+
+$mass_skip = false;
+
 if (hasRequest('action') && !hasRequest('regexpid')) {
 	if (!hasRequest('regexpids') || !is_array(getRequest('regexpids'))) {
 		access_deny();
 	}
 	else {
-		$regExpChk = DBfetch(DBSelect(
-			'SELECT COUNT(*) AS cnt FROM regexps re WHERE '.dbConditionInt('re.regexpid', getRequest('regexpids'))
+		$reg_exps = DBfetchArray(DBSelect(
+			'SELECT regexpid FROM regexps re WHERE '.dbConditionInt('re.regexpid', getRequest('regexpids'))
 		));
-		if ($regExpChk['cnt'] != count(getRequest('regexpids'))) {
-			access_deny();
+		if (count($reg_exps) != count(getRequest('regexpids'))) {
+			uncheckTableRows(null, zbx_objectValues($reg_exps, 'regexpid'));
+			show_error_message(_('No permissions to referred object or it does not exist!'));
+			$mass_skip = true;
 		}
 	}
 }
@@ -162,7 +161,7 @@ if (hasRequest('add') || hasRequest('update')) {
 	}
 	show_messages($result, $messageSuccess, $messageFailed);
 }
-elseif (hasRequest('action') && getRequest('action') == 'regexp.massdelete') {
+elseif (hasRequest('action') && getRequest('action') == 'regexp.massdelete' && !$mass_skip) {
 	$regExpIds = getRequest('regexpids', getRequest('regexpid', []));
 
 	zbx_value2array($regExpIds);
@@ -227,14 +226,14 @@ if (isset($_REQUEST['form'])) {
 	else {
 		$data['name'] = getRequest('name', '');
 		$data['test_string'] = getRequest('test_string', '');
-		$data['expressions'] = getRequest('expressions', [
+		$data['expressions'] = array_values(getRequest('expressions', [
 			[
 				'expression' => '',
 				'expression_type' => EXPRESSION_TYPE_INCLUDED,
 				'exp_delimiter' => ',',
 				'case_sensitive' => 0
 			]
-		]);
+		]));
 
 		foreach ($data['expressions'] as &$expression) {
 			if (!array_key_exists('case_sensitive', $expression)) {
