@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -32,61 +32,49 @@ if ($data['form_refresh'] == 0) {
 $proxyForm = (new CForm())
 	->setId('proxyForm')
 	->addVar('proxyid', $data['proxyid'])
-	->addVar('tls_accept', $data['tls_accept']);
+	->addVar('tls_accept', $data['tls_accept'])
+	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE);
 
 if ($data['status'] == HOST_STATUS_PROXY_PASSIVE && array_key_exists('interfaceid', $data)) {
 	$proxyForm->addVar('interfaceid', $data['interfaceid']);
 }
 
 $interfaceTable = (new CTable())
-	->setHeader([
-		_('IP address'),
-		_('DNS name'),
-		_('Connect to'),
-		_('Port')
-	])
+	->setHeader([_('IP address'), _('DNS name'), _('Connect to'), _('Port')])
 	->addRow([
 		(new CTextBox('ip', $data['ip'], false, 64))->setWidth(ZBX_TEXTAREA_INTERFACE_IP_WIDTH),
-		(new CTextBox('dns', $data['dns'], false, 64))->setWidth(ZBX_TEXTAREA_INTERFACE_DNS_WIDTH),
+		(new CTextBox('dns', $data['dns'], false, DB::getFieldLength('interface', 'dns')))
+			->setWidth(ZBX_TEXTAREA_INTERFACE_DNS_WIDTH),
 		(new CRadioButtonList('useip', (int) $data['useip']))
 			->addValue(_('IP'), INTERFACE_USE_IP)
 			->addValue(_('DNS'), INTERFACE_USE_DNS)
 			->setModern(true),
-		(new CTextBox('port', $data['port'], false, 64))->setWidth(ZBX_TEXTAREA_INTERFACE_PORT_WIDTH)
+		(new CTextBox('port', $data['port'], false, 64))
+			->setWidth(ZBX_TEXTAREA_INTERFACE_PORT_WIDTH)
+			->setAriaRequired()
 	]);
 
-// append hosts to form list
-$hosts_tween_box = new CTweenBox($proxyForm, 'proxy_hostids', $data['proxy_hostids']);
-foreach ($data['all_hosts'] as $host) {
-	// show only normal hosts, and discovered hosts monitored by the current proxy
-	// for new proxies display only normal hosts
-	if ($host['flags'] == ZBX_FLAG_DISCOVERY_NORMAL
-			|| ($data['proxyid'] != 0 && bccomp($data['proxyid'], $host['proxy_hostid']) == 0)) {
-
-		$hosts_tween_box->addItem(
-			$host['hostid'],
-			$host['name'],
-			null,
-			$host['proxy_hostid'] == 0
-				|| (bccomp($host['proxy_hostid'], $data['proxyid']) == 0 && $host['flags'] == ZBX_FLAG_DISCOVERY_NORMAL)
-		);
-	}
-}
-
 $proxy_form_list = (new CFormList('proxyFormList'))
-	->addRow(_('Proxy name'),
+	->addRow((new CLabel(_('Proxy name'), 'host'))->setAsteriskMark(),
 		(new CTextBox('host', $data['host'], false, 128))
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			->setAttribute('autofocus', 'autofocus')
+			->setAriaRequired()
 	)
-	->addRow(_('Proxy mode'),
+	->addRow((new CLabel(_('Proxy mode'), 'status')),
 		(new CRadioButtonList('status', (int) $data['status']))
 			->addValue(_('Active'), HOST_STATUS_PROXY_ACTIVE)
 			->addValue(_('Passive'), HOST_STATUS_PROXY_PASSIVE)
 			->setModern(true)
 	)
-	->addRow(_('Interface'), (new CDiv($interfaceTable))->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR))
-	->addRow(_('Hosts'), $hosts_tween_box->get(_('Proxy hosts'), _('Other hosts')))
+	->addRow((new CLabel(_('Interface'), 'proxy_interface'))->setAsteriskMark(),
+		(new CDiv($interfaceTable))
+			->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
+			->setId('proxy_interface')
+	)
+	->addRow(_('Proxy address'),
+		(new CTextBox('proxy_address', $data['proxy_address'], false, 255))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+	)
 	->addRow(_('Description'),
 		(new CTextArea('description', $data['description']))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 	);
@@ -110,11 +98,15 @@ $encryption_form_list = (new CFormList('encryption'))
 			->addItem((new CCheckBox('tls_in_psk'))->setLabel(_('PSK')))
 			->addItem((new CCheckBox('tls_in_cert'))->setLabel(_('Certificate')))
 	)
-	->addRow(_('PSK identity'),
-		(new CTextBox('tls_psk_identity', $data['tls_psk_identity'], false, 128))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+	->addRow((new CLabel(_('PSK identity'), 'tls_psk_identity'))->setAsteriskMark(),
+		(new CTextBox('tls_psk_identity', $data['tls_psk_identity'], false, 128))
+			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+			->setAriaRequired()
 	)
-	->addRow(_('PSK'),
-		(new CTextBox('tls_psk', $data['tls_psk'], false, 512))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+	->addRow((new CLabel(_('PSK'), 'tls_psk'))->setAsteriskMark(),
+		(new CTextBox('tls_psk', $data['tls_psk'], false, 512))
+			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+			->setAriaRequired()
 	)
 	->addRow(_('Issuer'),
 		(new CTextBox('tls_issuer', $data['tls_issuer'], false, 1024))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
