@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@ $data = [
 		'hosts' => ['updateExisting' => false, 'createMissing' => false],
 		'templates' => ['updateExisting' => false, 'createMissing' => false],
 		'templateScreens' => ['updateExisting' => false, 'createMissing' => false, 'deleteMissing' => false],
-		'templateLinkage' => ['createMissing' => false],
+		'templateLinkage' => ['createMissing' => false, 'deleteMissing' => false],
 		'applications' => ['createMissing' => false, 'deleteMissing' => false],
 		'items' => ['updateExisting' => false, 'createMissing' => false, 'deleteMissing' => false],
 		'discoveryRules' => ['updateExisting' => false, 'createMissing' => false, 'deleteMissing' => false],
@@ -84,7 +84,7 @@ if (hasRequest('rules_preset') && !hasRequest('rules')) {
 			$data['rules']['triggers'] = ['updateExisting' => true, 'createMissing' => true, 'deleteMissing' => false];
 			$data['rules']['graphs'] = ['updateExisting' => true, 'createMissing' => true, 'deleteMissing' => false];
 			$data['rules']['httptests'] = ['updateExisting' => true, 'createMissing' => true, 'deleteMissing' => false];
-			$data['rules']['templateLinkage'] = ['createMissing' => true];
+			$data['rules']['templateLinkage'] = ['createMissing' => true, 'deleteMissing' => false];
 			$data['rules']['valueMaps'] = ['updateExisting' => false, 'createMissing' => true];
 
 			$data['backurl'] = 'hosts.php';
@@ -104,7 +104,7 @@ if (hasRequest('rules_preset') && !hasRequest('rules')) {
 			$data['rules']['triggers'] = ['updateExisting' => true, 'createMissing' => true, 'deleteMissing' => false];
 			$data['rules']['graphs'] = ['updateExisting' => true, 'createMissing' => true, 'deleteMissing' => false];
 			$data['rules']['httptests'] = ['updateExisting' => true, 'createMissing' => true, 'deleteMissing' => false];
-			$data['rules']['templateLinkage'] = ['createMissing' => true];
+			$data['rules']['templateLinkage'] = ['createMissing' => true, 'deleteMissing' => false];
 			$data['rules']['valueMaps'] = ['updateExisting' => false, 'createMissing' => true];
 
 			$data['backurl'] = 'templates.php';
