@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 
 require_once dirname(__FILE__).'/include/config.inc.php';
 require_once dirname(__FILE__).'/include/hosts.inc.php';
-require_once dirname(__FILE__).'/include/hostgroups.inc.php';
 
 $page['title'] = _('Configuration of host groups');
 $page['file'] = 'hostgroups.php';
@@ -208,6 +207,15 @@ elseif (hasRequest('action')) {
 			show_messages($result, $messageSuccess, $messageFailed);
 		}
 	}
+
+	if (hasRequest('groups') && !$result) {
+		$groups = API::HostGroup()->get([
+			'groupids' => getRequest('groups'),
+			'output' => []
+		]);
+
+		uncheckTableRows(null, zbx_objectValues($groups, 'groupid'));
+	}
 }
 
 /*
