@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -701,17 +701,21 @@ if (isset($_REQUEST['form'])) {
 
 	$data['application_list'] = [];
 	if (!empty($data['hostid'])) {
-		$dbApps = DBselect(
-			'SELECT a.applicationid,a.name'.
-			' FROM applications a'.
-			' WHERE a.hostid='.zbx_dbstr($data['hostid']).
-				' AND a.flags='.ZBX_FLAG_DISCOVERY_NORMAL
-		);
-		while ($dbApp = DBfetch($dbApps)) {
-			$data['application_list'][$dbApp['applicationid']] = $dbApp['name'];
+		$db_applications = API::Application()->get([
+			'output' => ['name'],
+			'hostids' => $data['hostid'],
+			'filter' => ['flags' => ZBX_FLAG_DISCOVERY_NORMAL],
+			'preservekeys' => true
+		]);
+
+		CArrayHelper::sort($db_applications, ['name']);
+		foreach ($db_applications as $applicationid => $db_application) {
+			$data['application_list'][$applicationid] = $db_application['name'];
 		}
 	}
 
+	$i = 1;
+
 	foreach($data['steps'] as $stepid => $step) {
 		$pairs_grouped = [
 			'query_fields' => [],
@@ -726,6 +730,7 @@ if (isset($_REQUEST['form'])) {
 			}
 			$data['steps'][$stepid]['pairs'] = $pairs_grouped;
 		}
+		$data['steps'][$stepid]['no'] = $i++;
 	}
 
 	// render view
