@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -295,7 +295,7 @@ abstract class CGraphGeneral extends CApiService {
 		if ($graph['graphtype'] == GRAPH_TYPE_PIE || $graph['graphtype'] == GRAPH_TYPE_EXPLODED) {
 			$sumItems = 0;
 			foreach ($graph['gitems'] as $gitem) {
-				if ($gitem['type'] == GRAPH_ITEM_SUM) {
+				if (array_key_exists('type', $gitem) && $gitem['type'] == GRAPH_ITEM_SUM) {
 					$sumItems++;
 				}
 			}
@@ -418,6 +418,7 @@ abstract class CGraphGeneral extends CApiService {
 	 */
 	protected function validateItemsCreate(array $graphs) {
 		$itemIds = [];
+		$itemid_rules = ['type' => API_ID, 'flags' => API_NOT_EMPTY];
 
 		foreach ($graphs as $graph) {
 			// validate graph name
@@ -447,22 +448,20 @@ abstract class CGraphGeneral extends CApiService {
 				}
 			}
 
-			// add Y axis item IDs for persmission validation
-			if (isset($graph['ymin_type']) && $graph['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-				if (!isset($graph['ymin_itemid']) || zbx_empty($graph['ymin_itemid'])) {
-					self::exception(ZBX_API_ERROR_PARAMETERS,
-						_s($this->getErrorMsg(self::ERROR_MISSING_REQUIRED_VALUE), 'ymin_itemid')
-					);
+			// add Y min axis item ID for permission validation
+			if (array_key_exists('ymin_type', $graph) && $graph['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+				if (!CApiInputValidator::validate($itemid_rules, $graph['ymin_itemid'], 'ymin_itemid', $error)) {
+					self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 				}
 				else {
 					$itemIds[$graph['ymin_itemid']] = $graph['ymin_itemid'];
 				}
 			}
-			if (isset($graph['ymax_type']) && $graph['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-				if (!isset($graph['ymax_itemid']) || zbx_empty($graph['ymax_itemid'])) {
-					self::exception(ZBX_API_ERROR_PARAMETERS,
-						_s($this->getErrorMsg(self::ERROR_MISSING_REQUIRED_VALUE), 'ymax_itemid')
-					);
+
+			// add Y max axis item ID for permission validation
+			if (array_key_exists('ymax_type', $graph) && $graph['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+				if (!CApiInputValidator::validate($itemid_rules, $graph['ymax_itemid'], 'ymax_itemid', $error)) {
+					self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 				}
 				else {
 					$itemIds[$graph['ymax_itemid']] = $graph['ymax_itemid'];
@@ -555,6 +554,7 @@ abstract class CGraphGeneral extends CApiService {
 	 */
 	protected function validateItemsUpdate(array $graphs) {
 		$dbFields = ['itemid' => null];
+		$itemid_rules = ['type' => API_ID, 'flags' => API_NOT_EMPTY];
 
 		foreach ($graphs as $graph) {
 			// graph items are optional
@@ -577,24 +577,20 @@ abstract class CGraphGeneral extends CApiService {
 				}
 			}
 
-			// add Y min axis item IDs for persmission validation
-			if (isset($graph['ymin_type']) && $graph['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-				if (!isset($graph['ymin_itemid']) || zbx_empty($graph['ymin_itemid'])) {
-					self::exception(ZBX_API_ERROR_PARAMETERS,
-						_s($this->getErrorMsg(self::ERROR_MISSING_REQUIRED_VALUE), 'ymin_itemid')
-					);
+			// add Y min axis item ID for permission validation
+			if (array_key_exists('ymin_type', $graph) && $graph['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+				if (!CApiInputValidator::validate($itemid_rules, $graph['ymin_itemid'], 'ymin_itemid', $error)) {
+					self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 				}
 				else {
 					$itemIds[$graph['ymin_itemid']] = $graph['ymin_itemid'];
 				}
 			}
 
-			// add Y max axis item IDs for persmission validation
-			if (isset($graph['ymax_type']) && $graph['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-				if (!isset($graph['ymax_itemid']) || zbx_empty($graph['ymax_itemid'])) {
-					self::exception(ZBX_API_ERROR_PARAMETERS,
-						_s($this->getErrorMsg(self::ERROR_MISSING_REQUIRED_VALUE), 'ymax_itemid')
-					);
+			// add Y max axis item ID for permission validation
+			if (array_key_exists('ymax_type', $graph) && $graph['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+				if (!CApiInputValidator::validate($itemid_rules, $graph['ymax_itemid'], 'ymax_itemid', $error)) {
+					self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 				}
 				else {
 					$itemIds[$graph['ymax_itemid']] = $graph['ymax_itemid'];
