@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -391,6 +391,8 @@ class CTemplate extends CHostGeneral {
 
 		$templateDbFields = ['host' => null];
 
+		$host_name_parser = new CHostNameParser();
+
 		foreach ($templates as $template) {
 			// if visible name is not given or empty it should be set to host name
 			if ((!isset($template['name']) || zbx_empty(trim($template['name']))) && isset($template['host'])) {
@@ -406,11 +408,10 @@ class CTemplate extends CHostGeneral {
 				self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect input parameters.'));
 			}
 
-			if (!preg_match('/^'.ZBX_PREG_HOST_FORMAT.'$/', $template['host'])) {
-				self::exception(ZBX_API_ERROR_PARAMETERS, _s(
-					'Incorrect characters used for template name "%1$s".',
-					$template['host']
-				));
+			if ($host_name_parser->parse($template['host']) != CParser::PARSE_SUCCESS) {
+				self::exception(ZBX_API_ERROR_PARAMETERS,
+					_s('Incorrect characters used for template name "%1$s".', $template['host'])
+				);
 			}
 
 			if (isset($template['host'])) {
@@ -499,7 +500,8 @@ class CTemplate extends CHostGeneral {
 
 			$templateCopy = $template;
 
-			$template['templates_link'] = isset($template['templates']) ? $template['templates'] : null;
+			$template['templates_link'] = array_key_exists('templates', $template) ? $template['templates'] : null;
+
 			unset($template['templates'], $template['templateid'], $templateCopy['templates']);
 			$template['templates'] = [$templateCopy];
 
@@ -911,7 +913,7 @@ class CTemplate extends CHostGeneral {
 			DB::delete('hostmacro', ['hostid' => $templateIds]);
 
 			$this->massAdd([
-				'hosts' => $templates,
+				'templates' => $templates,
 				'macros' => $data['macros']
 			]);
 		}
@@ -1057,11 +1059,12 @@ class CTemplate extends CHostGeneral {
 			}
 		}
 
-		if (isset($data['host']) && !preg_match('/^'.ZBX_PREG_HOST_FORMAT.'$/', $data['host'])) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _s(
-				'Incorrect characters used for template name "%1$s".',
-				$data['host']
-			));
+		$host_name_parser = new CHostNameParser();
+
+		if (array_key_exists('host', $data) && $host_name_parser->parse($data['host']) != CParser::PARSE_SUCCESS) {
+			self::exception(ZBX_API_ERROR_PARAMETERS,
+				_s('Incorrect characters used for template name "%1$s".', $data['host'])
+			);
 		}
 	}
 
