@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -177,7 +177,7 @@ class CLineGraphDraw extends CGraphDraw {
 
 	protected function selectData() {
 		$this->data = [];
-		$now = time(null);
+		$now = time();
 
 		if (!isset($this->stime)) {
 			$this->stime = $now - $this->period;
@@ -230,7 +230,7 @@ class CLineGraphDraw extends CGraphDraw {
 				$to_resolve[] = 'trends';
 			}
 
-			// Otherwise, resolve user macro and parse the string. If successfull, convert to seconds.
+			// Otherwise, resolve user macro and parse the string. If successful, convert to seconds.
 			if ($to_resolve) {
 				$item = CMacrosResolverHelper::resolveTimeUnitMacros([$item], $to_resolve)[0];
 
@@ -295,8 +295,8 @@ class CLineGraphDraw extends CGraphDraw {
 
 					/* --------------------------------------------------
 						We are taking graph on 1px more than we need,
-						and here we are skiping first px, because of MOD (in SELECT),
-						it combines prelast point (it would be last point if not that 1px in begining)
+						and here we are skipping first px, because of MOD (in SELECT),
+						it combines prelast point (it would be last point if not that 1px in beginning)
 						and first point, but we still losing prelast point :(
 						but now we've got the first point.
 					--------------------------------------------------*/
@@ -419,10 +419,12 @@ class CLineGraphDraw extends CGraphDraw {
 						foreach (['min', 'max', 'avg'] as $var_name) {
 							$shift_var_name = 'shift_'.$var_name;
 							$curr_shift = &$curr_data[$shift_var_name];
-							$curr_var = &$curr_data[$var_name];
 							$prev_shift = &$prev_data[$shift_var_name];
 							$prev_var = &$prev_data[$var_name];
-							$curr_shift[$ci] = $prev_var[$ci] + $prev_shift[$ci];
+
+							$prev_var_ci = ($prev_var === null) ? 0 : $prev_var[$ci];
+							$prev_shift_ci = ($prev_shift === null) ? 0 : $prev_shift[$ci];
+							$curr_shift[$ci] = $prev_var_ci + $prev_shift_ci;
 						}
 					}
 					break;
@@ -553,11 +555,13 @@ class CLineGraphDraw extends CGraphDraw {
 			return $this->yaxismin;
 		}
 
-		if ($this->ymin_type == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+		if ($this->ymin_type == GRAPH_YAXIS_TYPE_ITEM_VALUE && $this->ymin_itemid != 0) {
 			$item = get_item_by_itemid($this->ymin_itemid);
-			$history = Manager::History()->getLastValues([$item]);
-			if (isset($history[$item['itemid']])) {
-				return $history[$item['itemid']][0]['value'];
+			if ($item) {
+				$history = Manager::History()->getLastValues([$item]);
+				if (isset($history[$item['itemid']])) {
+					return $history[$item['itemid']][0]['value'];
+				}
 			}
 		}
 
@@ -627,11 +631,13 @@ class CLineGraphDraw extends CGraphDraw {
 			return $this->yaxismax;
 		}
 
-		if ($this->ymax_type == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+		if ($this->ymax_type == GRAPH_YAXIS_TYPE_ITEM_VALUE && $this->ymax_itemid != 0) {
 			$item = get_item_by_itemid($this->ymax_itemid);
-			$history = Manager::History()->getLastValues([$item]);
-			if (isset($history[$item['itemid']])) {
-				return $history[$item['itemid']][0]['value'];
+			if ($item) {
+				$history = Manager::History()->getLastValues([$item]);
+				if (isset($history[$item['itemid']])) {
+					return $history[$item['itemid']][0]['value'];
+				}
 			}
 		}
 
@@ -741,14 +747,15 @@ class CLineGraphDraw extends CGraphDraw {
 				}
 			}
 			else {
-				$this->zero[$side] = $this->sizeY + $this->shiftY - (int) abs($this->m_minY[$side] / $this->unit2px[$side]);
+				$this->zero[$side] = $this->sizeY + $this->shiftY - abs(bcdiv($this->m_minY[$side],
+					$this->unit2px[$side]
+				));
 				$this->oxy[$side] = 0;
 			}
 		}
 	}
 
 	protected function calcMinMaxInterval() {
-		// init intervals
 		$intervals = [];
 		foreach ([1, 2, 3, 4] as $num) {
 			$dec = pow(0.1, $num);
@@ -757,7 +764,7 @@ class CLineGraphDraw extends CGraphDraw {
 			}
 		}
 
-		// check if items use B or Bps units
+		// Check if items use B or Bps units.
 		$leftBase1024 = false;
 		$rightBase1024 = false;
 
@@ -837,7 +844,7 @@ class CLineGraphDraw extends CGraphDraw {
 		$side = GRAPH_YAXIS_SIDE_LEFT;
 		$other_side = GRAPH_YAXIS_SIDE_RIGHT;
 
-		// invert sides and it bases, if left side not exist
+		// Invert sides and its bases, if left side doesn't exist.
 		if (!isset($this->axis_valuetype[GRAPH_YAXIS_SIDE_LEFT])) {
 			$side = GRAPH_YAXIS_SIDE_RIGHT;
 			$other_side = GRAPH_YAXIS_SIDE_LEFT;
@@ -863,14 +870,14 @@ class CLineGraphDraw extends CGraphDraw {
 		$tmp_minY = $this->m_minY;
 		$tmp_maxY = $this->m_maxY;
 
-		// calc interval
+		// Calculate interval.
 		$columnInterval = bcdiv(bcmul($this->gridPixelsVert, (bcsub($this->m_maxY[$side], $this->m_minY[$side]))), $this->sizeY);
 
 		$dist = bcmul(5, bcpow(10, 18));
 
 		$interval = 0;
 		foreach ($intervals as $int) {
-			// we must get a positive number
+			// We must get a positive number.
 			if (bccomp($int, $columnInterval) == -1) {
 				$t = bcsub($columnInterval, $int);
 			}
@@ -884,7 +891,7 @@ class CLineGraphDraw extends CGraphDraw {
 			}
 		}
 
-		// calculate interval, if left side use B or Bps
+		// Calculate interval, if left side use B or Bps.
 		if ($leftBase1024) {
 			$interval = getBase1024Interval($interval, $this->m_minY[$side], $this->m_maxY[$side]);
 		}
@@ -895,7 +902,7 @@ class CLineGraphDraw extends CGraphDraw {
 
 		$interval_other_side = 0;
 		foreach ($intervals as $int) {
-			// we must get a positive number
+			// We must get a positive number.
 			if (bccomp($int, $columnInterval) == -1) {
 				$t = bcsub($columnInterval, $int);
 			}
@@ -909,13 +916,13 @@ class CLineGraphDraw extends CGraphDraw {
 			}
 		}
 
-		// calculate interval, if right side use B or Bps
+		// Calculate interval, if right side use B or Bps.
 		if ($rightBase1024) {
 			$interval_other_side = getBase1024Interval($interval_other_side, $this->m_minY[$other_side],
 				$this->m_maxY[$other_side]);
 		}
 
-		// save original min and max items values
+		// Save original min and max items values.
 		foreach ($sides as $graphSide) {
 			$minY[$graphSide] = $this->m_minY[$graphSide];
 			$maxY[$graphSide] = $this->m_maxY[$graphSide];
@@ -928,13 +935,13 @@ class CLineGraphDraw extends CGraphDraw {
 			$maxY[$side] = 0;
 		}
 
-		// correcting MIN & MAX
+		// Correcting MIN & MAX.
 		$this->m_minY[$side] = bcmul(bcfloor(bcdiv($this->m_minY[$side], $interval)), $interval);
 		$this->m_maxY[$side] = bcmul(bcceil(bcdiv($this->m_maxY[$side], $interval)), $interval);
 		$this->m_minY[$other_side] = bcmul(bcfloor(bcdiv($this->m_minY[$other_side], $interval_other_side)), $interval_other_side);
 		$this->m_maxY[$other_side] = bcmul(bcceil(bcdiv($this->m_maxY[$other_side], $interval_other_side)), $interval_other_side);
 
-		// add intervals so min/max Y wouldn't be at the top
+		// Add intervals so min/max Y wouldn't be too close to graph's top/bottom edges.
 		foreach ($sides as $graphSide) {
 			if ($graphSide == $side) {
 				$tmpInterval = $interval;
@@ -954,7 +961,7 @@ class CLineGraphDraw extends CGraphDraw {
 			}
 		}
 
-		// calculate interval count for main and other side
+		// Calculate interval count for main and other side.
 		$this->gridLinesCount[$side] = bcceil(bcdiv(bcsub($this->m_maxY[$side], $this->m_minY[$side]), $interval));
 		$this->gridLinesCount[$other_side] = bcceil(bcdiv(bcsub($this->m_maxY[$other_side], $this->m_minY[$other_side]), $interval_other_side));
 
@@ -962,7 +969,7 @@ class CLineGraphDraw extends CGraphDraw {
 		$this->gridStep[$side] = $interval;
 
 		if (isset($this->axis_valuetype[$other_side])) {
-			// other side correction
+			// Other side correction.
 			$dist = bcsub($this->m_maxY[$other_side], $this->m_minY[$other_side]);
 			$interval = 1;
 
@@ -973,11 +980,11 @@ class CLineGraphDraw extends CGraphDraw {
 				}
 			}
 
-			// correcting MIN & MAX
+			// Correcting MIN & MAX on other side Y axis.
 			$this->m_minY[$other_side] = bcmul(bcfloor(bcdiv($this->m_minY[$other_side], $interval)), $interval);
 			$this->m_maxY[$other_side] = bcmul(bcceil(bcdiv($this->m_maxY[$other_side], $interval)), $interval);
 
-			// if we lowered min more than highed max - need additional recalculating
+			// Do recalculation in case if calculated min value is greater than calculated max value.
 			if (bccomp($tmp_maxY[$other_side], $this->m_maxY[$other_side]) == 1 || bccomp($tmp_minY[$other_side], $this->m_minY[$other_side]) == -1) {
 				$dist = bcsub($this->m_maxY[$other_side], $this->m_minY[$other_side]);
 				$interval = 0;
@@ -988,15 +995,15 @@ class CLineGraphDraw extends CGraphDraw {
 					}
 				}
 
-				// recorrecting MIN & MAX
+				// Correcting MIN & MAX values on other side Y axis.
 				$this->m_minY[$other_side] = bcmul(bcfloor(bcdiv($this->m_minY[$other_side], $interval)), $interval);
 				$this->m_maxY[$other_side] = bcmul(bcceil(bcdiv($this->m_maxY[$other_side], $interval)), $interval);
 			}
 
-			// calculate interval, if right side use B or Bps
+			// Calculate interval, if right side use B or Bps.
 			if (isset($rightBase1024)) {
 				$interval = getBase1024Interval($interval, $this->m_minY[$side], $this->m_maxY[$side]);
-				// recorrecting MIN & MAX
+				// Correcting MIN & MAX values on other side Y axis.
 				$this->m_minY[$other_side] = bcmul(bcfloor(bcdiv($this->m_minY[$other_side], $interval)), $interval);
 				$this->m_maxY[$other_side] = bcmul(bcceil(bcdiv($this->m_maxY[$other_side], $interval)), $interval);
 			}
@@ -1032,7 +1039,7 @@ class CLineGraphDraw extends CGraphDraw {
 			$this->validateMinMax($this->m_minY[$graphSide], $this->m_maxY[$graphSide]);
 		}
 
-		// division by zero
+		// Get diff between min/max Y values and fix potential division by zero.
 		$diff_val = bcsub($this->m_maxY[$side], $this->m_minY[$side]);
 		if (bccomp($diff_val, 0) == 0) {
 			$diff_val = 1;
@@ -1212,9 +1219,9 @@ class CLineGraphDraw extends CGraphDraw {
 	/**
 	 * Draw start or end date (and time) label.
 	 *
-	 * @param int $value		Unix time.
-	 * @param sring $format		Date time format.
-	 * @param int $position		Position on X axis.
+	 * @param int $value        Unix time.
+	 * @param string $format    Date time format.
+	 * @param int $position     Position on X axis.
 	 */
 	private function drawStartEndTimePeriod($value, $format, $position) {
 		$point = zbx_date2str(_($format), $value);
@@ -1310,6 +1317,7 @@ class CLineGraphDraw extends CGraphDraw {
 			['main' => SEC_PER_DAY, 'sub' => SEC_PER_HOUR * 6],			// 1 day and 6 hours
 			['main' => SEC_PER_DAY, 'sub' => SEC_PER_HOUR * 12],		// 1 day and 12 hours
 			['main' => SEC_PER_WEEK, 'sub' => SEC_PER_DAY],				// 1 week and 1 day
+			['main' => SEC_PER_WEEK, 'sub' => SEC_PER_DAY * 3],			// 1 week and 3 days
 			['main' => SEC_PER_MONTH, 'sub' => SEC_PER_WEEK],			// 1 month and 1 week
 			['main' => SEC_PER_MONTH, 'sub' => SEC_PER_WEEK * 2],		// 1 month and 2 weeks
 			['main' => SEC_PER_YEAR, 'sub' => SEC_PER_MONTH],			// 1 year and 30 days
@@ -1326,7 +1334,7 @@ class CLineGraphDraw extends CGraphDraw {
 			['main' => SEC_PER_YEAR * 80, 'sub' => SEC_PER_YEAR * 40]	// 80 years and 40 years
 		];
 
-		// Default inteval values.
+		// Default interval values.
 		$distance = SEC_PER_YEAR * 5;
 		$this->grid['horizontal']['main']['interval'] = 0;
 		$this->grid['horizontal']['sub']['interval'] = 0;
@@ -1469,9 +1477,9 @@ class CLineGraphDraw extends CGraphDraw {
 			$delta_x = bcsub($time, $prev_time) * $this->sizeX / $this->period;
 			$position += $delta_x;
 
-			// First element overlaping check.
+			// First element overlapping check.
 			if ($prev_time != $this->stime || $delta_x > $element_size['width']) {
-				// Last element overlaping check.
+				// Last element overlapping check.
 				if ($position > $this->sizeX - $element_size['width']) {
 					break;
 				}
@@ -1563,9 +1571,9 @@ class CLineGraphDraw extends CGraphDraw {
 
 			$newPow = false;
 			if ($byteStep) {
-				$maxYPow = convertToBase1024($maxY, 1024);
-				$minYPow = convertToBase1024($minY, 1024);
-				$powStep = 1024;
+				$maxYPow = convertToBase1024($maxY, ZBX_KIBIBYTE);
+				$minYPow = convertToBase1024($minY, ZBX_KIBIBYTE);
+				$powStep = ZBX_KIBIBYTE;
 			} else {
 				$maxYPow = convertToBase1024($maxY);
 				$minYPow = convertToBase1024($minY);
@@ -2377,7 +2385,7 @@ class CLineGraphDraw extends CGraphDraw {
 		$y_offsets = $this->shiftY + self::legendOffsetY;
 
 		if (!$this->with_vertical_padding) {
-			$y_offsets -= $this->m_showTriggers
+			$y_offsets -= ($this->m_showTriggers && count($this->triggers) > 0)
 				? static::DEFAULT_TOP_BOTTOM_PADDING / 2
 				: static::DEFAULT_TOP_BOTTOM_PADDING;
 		}
@@ -2512,6 +2520,7 @@ class CLineGraphDraw extends CGraphDraw {
 	public function drawDimensions() {
 		set_image_header();
 
+		$this->calculateTopPadding();
 		$this->selectTriggers();
 		$this->calcDimentions();
 
@@ -2616,11 +2625,19 @@ class CLineGraphDraw extends CGraphDraw {
 				$delay = $this->items[$item]['delay'];
 
 				if ($this->items[$item]['type'] == ITEM_TYPE_TRAPPER
+						|| ($this->items[$item]['type'] == ITEM_TYPE_ZABBIX_ACTIVE
+							&& preg_match('/^(event)?log(rt)?\[/', $this->items[$item]['key_']))
 						|| ($this->items[$item]['has_scheduling_intervals'] && $delay == 0)) {
 					$draw = true;
 				}
 				else {
-					$diff = abs($data['clock'][$i] - $data['clock'][$j]);
+					if ($data['clock'] === null) {
+						$diff = 0;
+					}
+					else {
+						$diff = abs($data['clock'][$i] - $data['clock'][$j]);
+					}
+
 					$cell = ($this->to_time - $this->from_time) / $this->sizeX;
 
 					if ($cell > $delay) {
