@@ -1,7 +1,7 @@
 <?php
 /*
  ** Zabbix
-** Copyright (C) 2001-2016 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -74,6 +74,28 @@ class CArrayHelper {
 		return $result;
 	}
 
+	/**
+	 * Select sub-array of array items with keys in given numeric range.
+	 *
+	 * @static
+	 *
+	 * @param array $array    Array with numeric keys to test for given range.
+	 * @param int   $start    Range start value.
+	 * @param int   $end      Range end value.
+	 *
+	 * @return array
+	 */
+	public static function getByKeysRange(array $array, $start, $end) {
+		$result = [];
+		foreach ($array as $key => $val) {
+			if ($key >= $start && $key <= $end) {
+				$result[$key] = $val;
+			}
+		}
+
+		return $result;
+	}
+
 	/**
 	 * Renames array elements keys according to given map.
 	 *
@@ -183,7 +205,8 @@ class CArrayHelper {
 
 		foreach ($a1 as $key => $value) {
 			// check if the values under $key are equal, skip arrays
-			if (isset($a2[$key]) && !is_array($value) && (string) $a1[$key] === (string) $a2[$key]) {
+			if (isset($a2[$key]) && !is_array($value) && !is_array($a2[$key])
+					&& (string) $a1[$key] === (string) $a2[$key]) {
 				unset($a1[$key]);
 			}
 		}
