@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2014 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -22,16 +22,18 @@
 class CAreaMap extends CTag {
 
 	public function __construct($name = '') {
-		parent::__construct('map', 'yes');
+		parent::__construct('map', true);
 		$this->setName($name);
 	}
 
 	public function addRectArea($x1, $y1, $x2, $y2, $href, $alt) {
-		return $this->addArea(array($x1, $y1, $x2, $y2), $href, $alt, 'rect');
+		$this->addArea([$x1, $y1, $x2, $y2], $href, $alt, 'rect');
+		return $this;
 	}
 
 	public function addArea($coords, $href, $alt, $shape) {
-		return $this->addItem(new CArea($coords, $href, $alt, $shape));
+		$this->addItem(new CArea($coords, $href, $alt, $shape));
+		return $this;
 	}
 
 	public function addItem($value) {
@@ -39,6 +41,7 @@ class CAreaMap extends CTag {
 			return $this->error('Incorrect value for addItem "'.$value.'".');
 		}
 
-		return parent::addItem($value);
+		parent::addItem($value);
+		return $this;
 	}
 }
