@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,9 +18,11 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
+
 $hostInventoryWidget = (new CWidget())
 	->setTitle(_('Host inventory'))
 	->setControls((new CForm('get'))
+		->setAttribute('aria-label', _('Main filter'))
 		->addItem((new CList())
 			->addItem([
 				new CLabel(_('Group'), 'groupid'),
@@ -30,11 +32,6 @@ $hostInventoryWidget = (new CWidget())
 		)
 	);
 
-// filter
-$filterForm = new CFilter('web.hostinventories.filter.state');
-
-$filterColumn = new CFormList();
-
 // getting inventory fields to make a drop down
 $inventoryFields = getHostInventories(true); // 'true' means list should be ordered by title
 $inventoryFieldsComboBox = (new CComboBox('filter_field', $this->data['filterField']))
@@ -43,23 +40,25 @@ foreach ($inventoryFields as $inventoryField) {
 	$inventoryFieldsComboBox->addItem($inventoryField['db_field'], $inventoryField['title']);
 }
 
-$filterColumn->addRow(
-		_('Field'),
-		[
-			$inventoryFieldsComboBox,
-			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-			new CComboBox('filter_exact', $this->data['filterExact'], null, [
-				0 => _('like'),
-				1 => _('exactly')
-			]),
-			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-			(new CTextBox('filter_field_value', $this->data['filterFieldValue']))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
-		]
+// filter
+$hostInventoryWidget->addItem(
+	(new CFilter(new CUrl('hostinventories.php')))
+		->setProfile($data['profileIdx'])
+		->setActiveTab($data['active_tab'])
+		->addFilterTab(_('Filter'), [
+			(new CFormList())->addRow(_('Field'), [
+				$inventoryFieldsComboBox,
+				(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+				new CComboBox('filter_exact', $this->data['filterExact'], null, [
+					0 => _('contains'),
+					1 => _('equals')
+				]),
+				(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+				(new CTextBox('filter_field_value', $this->data['filterFieldValue']))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+			])
+		])
 );
 
-$filterForm->addColumn($filterColumn);
-$hostInventoryWidget->addItem($filterForm);
-
 $table = (new CTableInfo())
 	->setHeader([
 		make_sorting_header(_('Host'), 'name', $this->data['sort'], $this->data['sortorder']),
