@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2016 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -71,8 +71,10 @@ CDate.prototype = {
 			sec = this.getSeconds();
 
 		/**
-		 * Append date suffix according to English rules e.g., 3 becomes 3rd
+		 * Append date suffix according to English rules e.g., 3 becomes 3rd.
+		 *
 		 * @param int date
+		 *
 		 * @return string
 		 */
 		var appSfx = function(date) {
@@ -86,9 +88,9 @@ CDate.prototype = {
 				return date + 'rd';
 			}
 			return date + 'th';
-		}
+		};
 
-		switch(format) {
+		switch (format) {
 			case 'd M Y H:i':
 				return appendZero(dt) + ' ' + shortMn[mnth] + ' ' + yr + ' ' + appendZero(hrs) + ':' + appendZero(mnts);
 			case 'j. M Y G:i':
@@ -147,25 +149,14 @@ CDate.prototype = {
 	},
 
 	setZBXDate: function(strdate) {
-		this.server = 1;
-
-		var theDate = {
-			Y: strdate.toString().substr(0, 4),
-			m: strdate.toString().substr(4, 2),
-			d: strdate.toString().substr(6, 2),
-			H: strdate.toString().substr(8, 2),
-			i: strdate.toString().substr(10, 2),
-			s: strdate.toString().substr(12, 2)
-		};
-
-		this.serverDate.setFullYear(theDate.Y);
-		this.serverDate.setMonth(theDate.m - 1);
-		this.serverDate.setDate(theDate.d);
-		this.serverDate.setHours(theDate.H);
-		this.serverDate.setMinutes(theDate.i);
-		this.serverDate.setSeconds(theDate.s);
-		this.serverDate.setMilliseconds(0);
-		this.calcTZdiff();
+		this.setTimeObject(
+			strdate.toString().substr(0, 4),
+			strdate.toString().substr(4, 2) - 1,
+			strdate.toString().substr(6, 2),
+			strdate.toString().substr(8, 2),
+			strdate.toString().substr(10, 2),
+			strdate.toString().substr(12, 2)
+		);
 
 		return this.getTime();
 	},
@@ -269,15 +260,38 @@ CDate.prototype = {
 		this.calcTZdiff();
 	},
 
-	setMonth: function(arg) {
+	setTimeObject: function(y, m, d, h, i, s) {
 		this.server = 1;
-		this.serverDate.setMonth(arg);
-		this.calcTZdiff();
-	},
+		function hasAttr(arg) {
+			return (typeof(arg) != 'undefined' && arg !== null);
+		}
+
+		if (hasAttr(y)) {
+			this.serverDate.setFullYear(y);
+		}
+
+		if (hasAttr(m) && hasAttr(d)) {
+			this.serverDate.setMonth(m, d);
+		}
+		else if (hasAttr(m)) {
+			this.serverDate.setMonth(m);
+		}
+		else if (hasAttr(d)) {
+			this.serverDate.setDate(d);
+		}
+
+		if (hasAttr(h)) {
+			this.serverDate.setHours(h);
+		}
+
+		if (hasAttr(i)) {
+			this.serverDate.setMinutes(i);
+		}
+
+		if (hasAttr(s)) {
+			this.serverDate.setSeconds(s);
+		}
 
-	setFullYear: function(arg) {
-		this.server = 1;
-		this.serverDate.setFullYear(arg);
 		this.calcTZdiff();
 	},
 
