@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2013 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -62,7 +62,6 @@ Cscreen.prototype = {
 
 		jQuery('.screenitem').droppable({
 			accept: '.draggable',
-			hoverClass: 'ui-sortable-placeholder',
 			drop: this.on_drop,
 			tolerance: 'pointer'
 		});
@@ -77,7 +76,7 @@ Cscreen.prototype = {
 		var x2 = dropDiv.data('xcoord');
 		var y2 = dropDiv.data('ycoord');
 
-		var url = new Curl(location.href);
+		var url = new Curl();
 		var params = {
 			ajaxAction: 'sw_pos',
 			output: 'ajax',
@@ -91,18 +90,18 @@ Cscreen.prototype = {
 
 		jQuery.post('screenedit.php', params, function(data) {
 			if (!isset('result', data) || !data.result) {
-				jQuery('<p>Ajax request error</p>').dialog({
-					modal: true,
-					resizable: false,
-					draggable: false
-				});
+				overlayDialogue({
+					'title': 'Error',
+					'content': jQuery('<span>').text('Ajax request error'),
+					'buttons': []
+				}, dropDiv);
 			}
 			else {
 				var parent = dropDiv.parent().get(0);
 				element.parent().get(0).appendChild(dropDiv.get(0));
 				parent.appendChild(element.get(0));
 
-				// replace "change" link href for emtpy cells
+				// replace "change" link href for empty cells
 				var link = jQuery(element).find('.empty_change_link')[0];
 				if (link) {
 					var href = jQuery(link).attr('href');
