@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -101,9 +101,12 @@
 			 * @param function       options.onUpdate  Callback function to execute once color has changed.
 			 */
 			init: function(options) {
-				var close = $('<button type="button" class="overlay-close-btn" title="' + t('Close') + '"/>').click(methods.hide);
-				options = $.extend(defaults, options||{});
-				overlay = $('<div class="overlay-dialogue" id="color_picker"/>').append(close).append(
+				var close = $('<button type="button" class="overlay-close-btn" title="' + t('S_CLOSE') + '"/>')
+					.click(methods.hide);
+				options = $.extend(defaults, options || {});
+				overlay = $('<div class="overlay-dialogue" id="color_picker"/>')
+					.append(close)
+					.append(
 					$.map(options.palette, function(colors) {
 						return $('<div class="color-picker"/>').append(
 							$.map(colors, function(color) {
@@ -111,15 +114,18 @@
 							})
 						);
 					})
-				).on('click', '.color-picker div', setColorHandler);
+					)
+					.on('click', '.color-picker div', setColorHandler);
 
 				overlay.appendTo($(options.appendTo));
+
 				if ($(options.appendTo).prop('tagName') !== 'BODY') {
 					$(options.appendTo).on('remove', function() {
 						overlay.remove();
 						overlay = null;
 					});
 				}
+
 				methods.hide();
 			},
 			/**
@@ -172,8 +178,9 @@
 				colorbox.css({
 					'color': background,
 					'background': background,
-					'title': background
-				});
+				})
+				.attr('title', background);
+
 				input.val(color);
 			},
 			/**
